@@ -6,3 +6,9 @@ class Conda(SimpleRockerExtension):
 
     name = "conda"
     depends_on_extension: tuple[str, ...] = ("curl", "user")
+
+    # Template arguments for both snippets
+    empy_args = {
+        "MINIFORGE_VERSION": "latest",
+        "CONDA_VERSION": "24.3.0-0",
+    }
