@@ -6,3 +6,8 @@ class Fzf(SimpleRockerExtension):
 
     name = "fzf"
     depends_on_extension = ["git_clone", "curl", "user"]
+
+    # Template arguments for both snippets
+    empy_args = {
+        "FZF_VERSION": "0.53.0",
+    }
