@@ -6,3 +6,8 @@ class Lazygit(SimpleRockerExtension):
 
     name = "lazygit"
     depends_on_extension = ("curl", "git", "git_clone")
+
+    # Template arguments for both snippets
+    empy_args = {
+        "LAZYGIT_VERSION": "0.41.0",
+    }
