@@ -6,3 +6,8 @@ class Pixi(SimpleRockerExtension):
 
     name = "pixi"
     depends_on_extension: tuple[str, ...] = ("curl", "user")
+
+    # Template arguments for both snippets
+    empy_args = {
+        "PIXI_VERSION": "0.55.0",
+    }
